@@ -23,6 +23,7 @@ default_parser_flags = (QueryParser.FLAG_PHRASE |
                         QueryParser.FLAG_BOOLEAN |
                         QueryParser.FLAG_LOVEHATE |
                         QueryParser.FLAG_SPELLING_CORRECTION |
+                        QueryParser.FLAG_BOOLEAN_ANY_CASE |
                         QueryParser.FLAG_WILDCARD)
 
 
@@ -893,7 +894,16 @@ class Database(object):
             if document:
                 yield doc
             else:
-                data = doc.get_data()
+                tries = 0
+                while True:
+                    try:
+                        data = doc.get_data()
+                        break
+                    except xapian.DatabaseModifiedError:
+                        if tries > RETRY_LIMIT:
+                            raise
+                        self.reopen()
+                        tries += 1
                 typ, data = loads(data)
                 yield self.record_factory(_lookup_schema(typ).from_flat(data))
 
